==> atlassian_connect_host-0.3.5.tar.gz: test/host_model_test.dart <==
library ac_dart.host_model.test;

import 'package:atlassian_connect_host/host_model.dart';
import 'package:unittest/unittest.dart';

main() {

  group('[Json]', () {
    final clientKey = '1234567890';
    final publicKey = 'MIGf....ZRWzwIDAQAB';
    final sharedSecret = '1ad6f705-fe0b-4111-9551-7ce5d81d2884';
    final baseUrl = Uri.parse('http://storm.dyn.syd.atlassian.com:2990/jira');
    final productType = 'confluence';

    final rego = new MutableAcHostRegistration()
        ..sharedSecret = sharedSecret
        ..hostDetails = (new MutableAcHostDetails()
            ..baseUrl = baseUrl
            ..key = clientKey
            ..productType = ProductType.confluence
            ..publicKey = publicKey);

    group('[toJson]', () {
      toJson() => rego.toJson();

      getRegoField(String key) => toJson()[key];
      getDetailsField(String key) => getRegoField('hostDetails')[key];

      test('sharedSecret marshals correctly', () {
        expect(getRegoField('sharedSecret'), equals(sharedSecret));
      });

      test('hostDetails marshals into correct type', () {
        expect(getRegoField('hostDetails'), new isInstanceOf<Map>());
      });

      test('key marshals into correctly', () {
        expect(getDetailsField('key'), equals(clientKey));
      });

      test('baseUrl marshals into correctly', () {
        expect(getDetailsField('baseUrl'), equals(baseUrl.toString()));
      });

      test('productType marshals into correctly', () {
        expect(getDetailsField('productType'), equals(productType));
      });

      test('publicKey marshals into correctly', () {
        expect(getDetailsField('publicKey'), equals(publicKey));
      });

    });
  
    group('[fromJson]', () {
      fromJson() => new AcHostRegistration.fromJson(rego.toJson());
      hostDetails() => fromJson().hostDetails;
      
      test('sharedSecret unmarshals correctly', () {
        expect(fromJson().sharedSecret, equals(sharedSecret));
      });

      test('hostDetails unmarshals', () {
        expect(fromJson().hostDetails, isNotNull);
      });

      test('key unmarshals into correctly', () {
        expect(hostDetails().key, equals(clientKey));
      });

      test('baseUrl unmarshals into correctly', () {
        expect(hostDetails().baseUrl, equals(baseUrl));
      });

      test('productType unmarshals into correctly', () {
        expect(hostDetails().productType.literal, equals(productType));
      });

      test('publicKey unmarshals into correctly', () {
        expect(hostDetails().publicKey, equals(publicKey));
      });
    });

  });
  
}

==> atlassian_connect_host-0.4.0.tar.gz: test/host_model_test.dart <==
library ac_dart.host_model.test;

import 'package:atlassian_connect_host/host_model.dart';
import 'package:unittest/unittest.dart';

main() {

  group('[Json]', () {
    final clientKey = '1234567890';
    final publicKey = 'MIGf....ZRWzwIDAQAB';
    final sharedSecret = '1ad6f705-fe0b-4111-9551-7ce5d81d2884';
    final baseUrl = Uri.parse('http://storm.dyn.syd.atlassian.com:2990/jira');
    final productType = 'confluence';

    final rego = new AcHostRegistration.build(
              sharedSecret: sharedSecret,
              hostDetails: (new AcHostDetails.build(
                  key: clientKey,
                  baseUrl: baseUrl,
                  productType: ProductType.confluence,
                  publicKey: publicKey)));

    group('[toJson]', () {
      toJson() => rego.toJson();

      getRegoField(String key) => toJson()[key];
      getDetailsField(String key) => getRegoField('hostDetails')[key];

      test('sharedSecret marshals correctly', () {
        expect(getRegoField('sharedSecret'), equals(sharedSecret));
      });

      test('hostDetails marshals into correct type', () {
        expect(getRegoField('hostDetails'), new isInstanceOf<Map>());
      });

      test('key marshals into correctly', () {
        expect(getDetailsField('key'), equals(clientKey));
      });

      test('baseUrl marshals into correctly', () {
        expect(getDetailsField('baseUrl'), equals(baseUrl.toString()));
      });

      test('productType marshals into correctly', () {
        expect(getDetailsField('productType'), equals(productType));
      });

      test('publicKey marshals into correctly', () {
        expect(getDetailsField('publicKey'), equals(publicKey));
      });

    });
  
    group('[fromJson]', () {
      fromJson() => new AcHostRegistration.fromJson(rego.toJson());
      hostDetails() => fromJson().hostDetails;
      
      test('sharedSecret unmarshals correctly', () {
        expect(fromJson().sharedSecret, equals(sharedSecret));
      });

      test('hostDetails unmarshals', () {
        expect(fromJson().hostDetails, isNotNull);
      });

      test('key unmarshals into correctly', () {
        expect(hostDetails().key, equals(clientKey));
      });

      test('baseUrl unmarshals into correctly', () {
        expect(hostDetails().baseUrl, equals(baseUrl));
      });

      test('productType unmarshals into correctly', () {
        expect(hostDetails().productTypeLiteral, equals(productType));
      });

      test('publicKey unmarshals into correctly', () {
        expect(hostDetails().publicKey, equals(publicKey));
      });
    });

  });
  
}
